@@ -8,14 +8,15 @@ head(o2cons)
 ## ------------------------------------------------------------------------
 model1 <- RM(O2 ~ Group * Staphylococci * Time, data = o2cons, 
              subject = "Subject", no.subf = 2, iter = 1000, 
-             resampling = "Perm", CPU = 1, seed = 1234)
+             resampling = "Perm", seed = 1234)
 summary(model1)
 
 ## ------------------------------------------------------------------------
 data(EEG)
 EEG_model <- RM(resp ~ sex * diagnosis * feature * region, 
-                     data = EEG, subject = "id", no.subf = 2, resampling = "WildBS",
-                     iter = 1000,  alpha = 0.01, CPU = 1, seed = 987)
+                data = EEG, subject = "id", within = c("feature", "region"), 
+                resampling = "WildBS",
+                iter = 1000,  alpha = 0.01, seed = 987)
 summary(EEG_model)
 
 ## ------------------------------------------------------------------------
@@ -27,7 +28,7 @@ plot(EEG_model, factor = "sex:diagnosis:feature", legendpos = "center", gap = 0.
 data(EEG)
 EEG_MANOVA <- MANOVA(resp ~ sex * diagnosis, 
                      data = EEG, subject = "id", resampling = "paramBS", 
-                     iter = 1000,  alpha = 0.01, CPU = 1, seed = 987)
+                     iter = 1000,  alpha = 0.01, seed = 987)
 summary(EEG_MANOVA)
 
 ## ------------------------------------------------------------------------
@@ -41,14 +42,14 @@ rate     <- gl(2,10, labels = c("Low", "High"))
 additive <- gl(2, 5, length = 20, labels = c("Low", "High"))
 
 example <- data.frame(tear, gloss, opacity, rate, additive)
-fit <- MANOVA.wide(cbind(tear, gloss, opacity) ~ rate * additive, data = example, iter = 1000, CPU = 1)
+fit <- MANOVA.wide(cbind(tear, gloss, opacity) ~ rate * additive, data = example, iter = 1000)
 summary(fit)
 
 ## ------------------------------------------------------------------------
 if (requireNamespace("HSAUR3", quietly = TRUE)) {
 library(HSAUR3)
 data(water)
-test <- MANOVA.wide(cbind(mortality, hardness) ~ location, data = water, iter = 1000, resampling = "paramBS", CPU = 1, seed = 123)
+test <- MANOVA.wide(cbind(mortality, hardness) ~ location, data = water, iter = 1000, resampling = "paramBS", seed = 123)
 summary(test)
 cr <- conf.reg(test)
 cr
@@ -65,8 +66,7 @@ simCI(EEG_MANOVA, contrast = "pairwise", type = "Tukey")
 #simCI(EEG_MANOVA, contrast = "pairwise", type = "Tukey", interaction = FALSE, factor = "diagnosis")
 
 ## ------------------------------------------------------------------------
-oneway <- MANOVA.wide(cbind(brainrate_temporal, brainrate_central) ~ diagnosis, data = EEGwide,
-                      iter = 1000, CPU = 1)
+oneway <- MANOVA.wide(cbind(brainrate_temporal, brainrate_central) ~ diagnosis, data = EEGwide, iter = 1000)
 # and a user-defined contrast matrix
 H <- as.matrix(cbind(rep(1, 5), -1*Matrix::Diagonal(5)))
 # user-specified comparison
@@ -74,18 +74,16 @@ simCI(oneway, contrast = "user-defined", contmat = H)
 
 ## ------------------------------------------------------------------------
 model_sex <- MANOVA.wide(cbind(brainrate_temporal, brainrate_central, brainrate_frontal,
-                            complexity_temporal, complexity_central, complexity_frontal) ~ sex,
-                      data = EEGwide,
-                      iter = 1000, seed = 987, CPU = 1)
+                            complexity_temporal, complexity_central, complexity_frontal) ~ sex, data = EEGwide, iter = 1000, seed = 987)
 summary(model_sex)
 
 ## ------------------------------------------------------------------------
-EEG1 <- MANOVA.wide(brainrate_temporal ~ sex, data = EEGwide, iter = 1000, seed = 987, CPU = 1)
-EEG2 <- MANOVA.wide(brainrate_central ~ sex, data = EEGwide, iter = 1000, seed = 987, CPU = 1)
-EEG3 <- MANOVA.wide(brainrate_frontal ~ sex, data = EEGwide, iter = 1000, seed = 987, CPU = 1)
-EEG4 <- MANOVA.wide(complexity_temporal ~ sex, data = EEGwide, iter = 1000, seed = 987, CPU = 1)
-EEG5 <- MANOVA.wide(complexity_central ~ sex, data = EEGwide, iter = 1000, seed = 987, CPU = 1)
-EEG6 <- MANOVA.wide(complexity_frontal ~ sex, data = EEGwide, iter = 1000, seed = 987, CPU = 1)
+EEG1 <- MANOVA.wide(brainrate_temporal ~ sex, data = EEGwide, iter = 1000, seed = 987)
+EEG2 <- MANOVA.wide(brainrate_central ~ sex, data = EEGwide, iter = 1000, seed = 987)
+EEG3 <- MANOVA.wide(brainrate_frontal ~ sex, data = EEGwide, iter = 1000, seed = 987)
+EEG4 <- MANOVA.wide(complexity_temporal ~ sex, data = EEGwide, iter = 1000, seed = 987)
+EEG5 <- MANOVA.wide(complexity_central ~ sex, data = EEGwide, iter = 1000, seed = 987)
+EEG6 <- MANOVA.wide(complexity_frontal ~ sex, data = EEGwide, iter = 1000, seed = 987)
 
 ## ------------------------------------------------------------------------
 p.adjust(c(EEG1$resampling[, 2], EEG2$resampling[, 2], EEG3$resampling[, 2],
@@ -100,7 +98,7 @@ set.seed(123)
 curdies$dug2 <- curdies$dugesia + rnorm(36)
 
 # first possibility: MANOVA.wide
-fit1 <- MANOVA.wide(cbind(dugesia, dug2) ~ season + season:site, data = curdies, iter = 1000, nested.levels.unique = TRUE, seed = 123, CPU = 1)
+fit1 <- MANOVA.wide(cbind(dugesia, dug2) ~ season + season:site, data = curdies, iter = 1000, nested.levels.unique = TRUE, seed = 123)
 
 # second possibility: MANOVA (long format)
 dug <- c(curdies$dugesia, curdies$dug2)
@@ -108,8 +106,7 @@ season <- rep(curdies$season, 2)
 site <- rep(curdies$site, 2)
 curd <- data.frame(dug, season, site, subject = rep(1:36, 2))
 
-fit2 <- MANOVA(dug ~ season + season:site, data = curd, subject = "subject", nested.levels.unique = TRUE, seed = 123, iter = 1000,
-               CPU = 1)
+fit2 <- MANOVA(dug ~ season + season:site, data = curd, subject = "subject", nested.levels.unique = TRUE, seed = 123, iter = 1000)
 
 # comparison of results
 summary(fit1)
@@ -120,7 +117,7 @@ summary(fit2)
 library(tidyr)
 eeg <- spread(EEG, feature, resp)
 head(eeg)
-fit <- multRM(cbind(brainrate, complexity) ~ sex * region, data = eeg, subject = "id", within = "region", iter = 200, CPU = 1)
+fit <- multRM(cbind(brainrate, complexity) ~ sex * region, data = eeg, subject = "id", within = "region", iter = 1000)
 summary(fit)
 
 ## ------------------------------------------------------------------------
